;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gdscript-mode" "20260121.1027"
  "Major mode for Godot's GDScript language."
  '((emacs "26.3"))
  :url "https://github.com/godotengine/emacs-gdscript-mode/"
  :commit "ec244ff631fdf8b4b5674f9c18d2a37c2c5894e6"
  :revdesc "ec244ff631fd"
  :keywords '("languages")
  :authors '(("Nathan Lovato" . "nathan@gdquest.com")
             ("Fabián E. Gallina" . "fgallina@gnu.org"))
  :maintainers '(("Jen-Chieh Shen" . "jcs090218@gmail.com")))
